@@ -4,17 +4,17 @@
 ##
 
 gqi.odfvmflines <-
-function(gdi="gqi", run=TRUE, fbase=NULL, roi=NULL,  rg=c(1,1), swap=FALSE, lambda=NULL, depth=3, btoption=2, threshold=0.4, kdir=4, zfactor=5, showglyph=FALSE, snapshot=FALSE, showimage="linesgfa", bview="coronal", savedir=tempdir(), pngfig="odfvmf", bg="white", texturefile=NA)
+function(gdi="gqi", run=TRUE, fbase=NULL, roi=NULL,  rg=c(1,1), swap=FALSE, lambda=NULL, depth=3, btoption=2, threshold=0.4, kdir=4, zfactor=5, showglyph=FALSE, snapshot=FALSE, showimage="linesgfa", bview="coronal", savedir=tempdir(), pngfig="odfvmf", bg="white", texture=NULL, ...)
 {
   gdimethods <- c("gqi", "gqi2")
   gdimethod <- match(gdi, gdimethods)
   startctl=list(E="softmax", minalpha=8, start="s", maxiter=200) ## movMF inits
   showimages <- c("none", "gfa", "lines", "linesgfa", "linesrgbmap", "linesdata") ## map types
   kshow <- match(showimage, showimages)
-	stopifnot(is.na(kshow) != TRUE)
+  stopifnot(is.na(kshow) != TRUE)
   bviews <- c("sagittal", "coronal", "axial")
   kv <- match(bview, bviews)
-	stopifnot(is.na(kv) != TRUE)
+  stopifnot(is.na(kv) != TRUE)
   ##---------
   # generate S2 grid
   s2 <- s2tessel.zorder(depth=depth, viewgrid=FALSE)
@@ -34,11 +34,14 @@ function(gdi="gqi", run=TRUE, fbase=NULL, roi=NULL,  rg=c(1,1), swap=FALSE, lamb
       bvec <- scantable(fbase=fbase, filename="data.bvec")
       bvec <- matrix(bvec, ncol=3)
       btable <- cbind(bval,bvec)
+      rm(bval, bvec)
     }
     else stop()
   }
   ##----------------------------
-  cat("Reading data ...")
+  gc()
+  cat("Reading data ...\n")
+  ptm <- proc.time()
   img.nifti  <- readniidata(fbase=fbase, filename="data.nii.gz")
   volimg <- img.nifti@.Data  
   if(is.null(roi))
@@ -48,10 +51,13 @@ function(gdi="gqi", run=TRUE, fbase=NULL, roi=NULL,  rg=c(1,1), swap=FALSE, lamb
     mask.nifti <-
       readniidata(fbase=fbase, filename=paste(roi,".nii.gz", sep=""))
   volmask <- mask.nifti@.Data  
+  print(proc.time() - ptm)
+  rm(img.nifti, mask.nifti)
+  gc()
   ##----------------------------
-  volgfa <- array(0, dim=dim(volmask)) ## gfas map
-  V1 <- array(0, dim=c(dim(volmask), 3)) ## V1 direction
-  d <- dim(volimg)
+  d <- dim(volmask)
+  volgfa <- array(0, dim=d)   ## gfas map
+  V1 <- array(0, dim=c(d, 3)) ## V1 direction
   if(is.null(rg)) {
     switch(kv,
       { nslices <- d[1]}, # sagittal,
@@ -79,6 +85,7 @@ function(gdi="gqi", run=TRUE, fbase=NULL, roi=NULL,  rg=c(1,1), swap=FALSE, lamb
   # rglstart()
   for (sl in (first:last)) {
     cat("slice",sl,"\n")
+    ptm <- proc.time()
     #-------------------
     slicedata <- read.slice(img=volimg, mask=volmask, slice=sl,
        swap=swap, bview=bview)
@@ -129,11 +136,11 @@ function(gdi="gqi", run=TRUE, fbase=NULL, roi=NULL,  rg=c(1,1), swap=FALSE, lamb
         vx <- odfvertices[-ith,]
         n <- dim(vx)[1]
         ## Fit a vMF mixture  with k=2
-        y1 <- movMF(vx, k=2, control=startctl) 
+        y1 <- movMF::movMF(vx, k=2, control=startctl) 
         par1 <- logb(n)*npar1
         bic1 <- 2*logLik(y1) - par1
         ## Fit a vMF mixture  with k=4
-        y2 <- movMF(vx, k=4, control=startctl) 
+        y2 <- movMF::movMF(vx, k=4, control=startctl) 
         par2 <- logb(n)*npar2
         bic2 <- 2*logLik(y2) - par2
         if(bic1 >= bic2) { yy <- y1 }
@@ -149,8 +156,8 @@ function(gdi="gqi", run=TRUE, fbase=NULL, roi=NULL,  rg=c(1,1), swap=FALSE, lamb
         v1perslice[m,] <- pk$pcoords[,1]
         ## optional glyph visualization
         if(showglyph) {
-					if(rgl.cur() == 0) rglinit()
-					else rgl.clear()
+          if(rgl.cur() == 0) rglinit()
+          else rgl.clear()
           if(pk$np > 2) {
             plotglyph(odfs[,m], odfvertices, pk, kdir=kdir)
             pp <- readline(
@@ -227,13 +234,12 @@ function(gdi="gqi", run=TRUE, fbase=NULL, roi=NULL,  rg=c(1,1), swap=FALSE, lamb
         par3d('windowRect'=c(0,0,600,600), 'zoom'=0.6, skipRedraw=FALSE)
         rgl.bringtotop()
       }
-      texture <- FALSE
       switch(kshow,
       { ovr <- FALSE },
       { ovr <- TRUE; imgfa <- matrix(0, nr, nc); imgfa[z2d ] <- gfas },
       { ovr <- FALSE },
       { ovr <- TRUE; imgfa <- matrix(0, nr, nc); imgfa[z2d ] <- gfas },
-      { ovr<- TRUE; texture <- TRUE; zfactor=0.1;
+      { ovr<- TRUE; zfactor=0.1;
         imgfa <- matrix(0, nr, nc); imgfa[z2d ] <- gfas }, # linesrgb
       { ovr <- TRUE;
       imgfa <- slicedata$niislicets[,,1] * slicedata$mask;
@@ -241,9 +247,7 @@ function(gdi="gqi", run=TRUE, fbase=NULL, roi=NULL,  rg=c(1,1), swap=FALSE, lamb
       if(ovr) {
         bg3d(col=bg) 
         light3d()  
-        gfasurf3d(imgfa, zfactor=zfactor, alpha=0.6, texture=texture,
-          texturefile=texturefile)
-        # rgl.viewpoint(theta=0, phi=0)
+        gfasurf3d(imgfa, zfactor=zfactor, alpha=0.6, texture=texture, ...)
         rgl.viewpoint(theta=0, phi=15)
          par3d('windowRect'=c(0,0,600,600), 'zoom'=0.6, skipRedraw=FALSE)
           rgl.bringtotop()
@@ -262,13 +266,13 @@ function(gdi="gqi", run=TRUE, fbase=NULL, roi=NULL,  rg=c(1,1), swap=FALSE, lamb
       if(pp == "n" ) { break; }
       else { rgl.clear( type = "shapes" ) }
     }
+    print(proc.time() - ptm)
   }
-  cat("\n")
   ## save V1 directions
-  if(run) {
-    v1file <- paste(savedir,"/V1list.RData",sep="")
-    save(v1list, file=v1file) # list of v1 vectors 
-    cat("saved V1 directions ",v1file,"\n")
-  }
+  # if(run) {
+  #   v1file <- file.path(savedir,"V1list.RData")
+  #   save(v1list, file=v1file) # list of v1 vectors 
+  #   cat("saved V1 directions ",v1file,"\n")
+  # }
 }
 
